Struct orchestrator::default_memory::DefaultMemory

source ·
pub struct DefaultMemory { /* private fields */ }
MUST be used only for testing, not recomended in production

saves password as it is, and doesn’t do any sanification…

in addition to that all users are admin by default

Implementations

source

impl DefaultMemory

source

pub fn init<S: ExecutorGlobalState>() -> Box<dyn Memory<S>>

Generates a new DefaultMemory