Function orchestrator::default_memory::has_cycles
source · pub fn has_cycles(vertex: &HashMap<String, String>) -> boolExpand description
helper function used to check if there are cycles. It is public in order to be used by other memory implementations.