Struct orchestrator::default_memory::DefaultMemory
source · pub struct DefaultMemory { /* private fields */ }Expand description
MUST be used only for testing, not recomended in production
saves password as it is, and doesn’t do any sanification…
in addition to that all users are admin by default
Implementations
sourceimpl DefaultMemory
impl DefaultMemory
sourcepub fn init<S: ExecutorGlobalState>() -> Box<dyn Memory<S>>
pub fn init<S: ExecutorGlobalState>() -> Box<dyn Memory<S>>
Generates a new DefaultMemory